@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: copyin.c,v 1.7 1998/04/11 08:26:54 rob Exp $
+ * $Id: copyin.c,v 1.8 1998/11/02 22:08:25 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -70,7 +70,7 @@ static
 int fork_macb(int ifile, hfsfile *ofile, unsigned long size)
 {
   char buf[HFS_BLOCKSZ * 4];
-  long chunk, bytes;
+  unsigned long chunk, bytes;
 
   while (size)
     {
@@ -78,7 +78,7 @@ int fork_macb(int ifile, hfsfile *ofile, unsigned long size)
 	(size + (MACB_BLOCKSZ - 1)) & ~(MACB_BLOCKSZ - 1) : sizeof(buf);
 
       bytes = read(ifile, buf, chunk);
-      if (bytes == -1)
+      if (bytes == (unsigned long) -1)
 	{
 	  ERROR(errno, "error reading data");
 	  return -1;
@@ -92,7 +92,7 @@ int fork_macb(int ifile, hfsfile *ofile, unsigned long size)
       chunk = (size > bytes) ? bytes : size;
 
       bytes = hfs_write(ofile, buf, chunk);
-      if (bytes == -1)
+      if (bytes == (unsigned long) -1)
 	{
 	  ERROR(errno, hfs_error);
 	  return -1;
@@ -388,7 +388,7 @@ hfsfile *opendst(hfsvol *vol, const char *dstname, const char *hint,
 {
   hfsdirent ent;
   hfsfile *file;
-  long cwd;
+  unsigned long cwd;
 
   if (hfs_stat(vol, dstname, &ent) != -1 &&
       (ent.flags & HFS_ISDIR))
