@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: darray.c,v 1.6 1998/04/11 08:26:55 rob Exp $
+ * $Id: darray.c,v 1.7 1998/11/02 22:08:26 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -98,7 +98,7 @@ void *darr_append(darray *array, void *elem)
   char *eltend = array->eltend;
   size_t elemsz = array->elemsz;
 
-  if (eltend - array->mem == array->memsz)
+  if ((size_t) (eltend - array->mem) == array->memsz)
     {
       char *newmem;
       size_t newsz;
