@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: dlist.c,v 1.6 1998/04/11 08:26:55 rob Exp $
+ * $Id: dlist.c,v 1.7 1998/11/02 22:08:27 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -78,13 +78,13 @@ int dl_size(dlist *list)
  */
 int dl_append(dlist *list, const char *str)
 {
-  int len;
+  size_t len;
 
   len = strlen(str) + 1;
 
   /* make sure there is room */
 
-  if (sizeof(char *) + len > list->strs - (char *) list->eltend)
+  if (sizeof(char *) + len > (size_t) (list->strs - (char *) list->eltend))
     {
       dlist newlist;
       size_t strsz;
