@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: dstring.c,v 1.6 1998/04/11 08:26:55 rob Exp $
+ * $Id: dstring.c,v 1.7 1998/11/02 22:08:28 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -44,11 +44,11 @@ void dstr_init(dstring *string)
  * NAME:	dstring->append()
  * DESCRIPTION:	append to a dynamic string
  */
-int dstr_append(dstring *string, const char *str, int len)
+int dstr_append(dstring *string, const char *str, size_t len)
 {
-  int newlen;
+  size_t newlen;
 
-  if (len < 0)
+  if (len == (size_t) -1)
     len = strlen(str);
 
   newlen = string->len + len;
@@ -107,7 +107,7 @@ int dstr_length(dstring *string)
  * NAME:	dstring->shrink()
  * DESCRIPTION:	truncate a dynamic string to a shorter length
  */
-void dstr_shrink(dstring *string, int len)
+void dstr_shrink(dstring *string, size_t len)
 {
   if (len < string->len)
     string->len = len;
