@@ -16,19 +16,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: dstring.h,v 1.6 1998/04/11 08:26:55 rob Exp $
+ * $Id: dstring.h,v 1.7 1998/11/02 22:08:29 rob Exp $
  */
 
 typedef struct {
   char *str;
-  int len;
+  size_t len;
   size_t space;
   char sbuf[50];
 } dstring;
 
 void dstr_init(dstring *);
-int dstr_append(dstring *, const char *, int);
+int dstr_append(dstring *, const char *, size_t);
 char *dstr_string(dstring *);
 int dstr_length(dstring *);
-void dstr_shrink(dstring *, int);
+void dstr_shrink(dstring *, size_t);
 void dstr_free(dstring *);
