@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hattrib.c,v 1.10 1998/01/08 21:13:01 rob Exp $
+ * $Id: hattrib.c,v 1.8 1998/08/31 04:27:17 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -40,8 +40,9 @@ static
 int usage(void)
 {
   fprintf(stderr,
-	  "Usage: %s [-t TYPE] [-c CREA] [-|+i] [-|+l] hfs-path [...]\n",
-	  argv0);
+	  "Usage: %s [-t TYPE] [-c CREA] [-|+i] [-|+l] hfs-path [...]\n"
+	  "       %s -b hfs-path\n",
+	  argv0, argv0);
 
   return 1;
 }
@@ -53,7 +54,7 @@ int usage(void)
 int hattrib_main(int argc, char *argv[])
 {
   const char *type = 0, *crea = 0;
-  int invis = 0, lock = 0;
+  int invis = 0, lock = 0, bless = 0;
   hfsvol *vol;
   int fargc;
   char **fargv;
@@ -102,6 +103,10 @@ int hattrib_main(int argc, char *argv[])
 	      lock = -1;
 	      continue;
 
+	    case 'b':
+	      bless = 1;
+	      continue;
+
 	    default:
 	      return usage();
 	    }
@@ -136,6 +141,9 @@ int hattrib_main(int argc, char *argv[])
       return 1;
     }
 
+  if (bless && (lock || invis || type || crea || argc - i > 1))
+    return usage();
+
   vol = hfsutil_remount(hcwd_getvol(-1), HFS_MODE_ANY);
   if (vol == 0)
     return 1;
@@ -144,40 +152,72 @@ int hattrib_main(int argc, char *argv[])
 
   if (result == 0)
     {
-      for (i = 0; i < fargc; ++i)
-	{
-	  hfsdirent ent;
+      hfsdirent ent;
 
-	  if (hfs_stat(vol, fargv[i], &ent) == -1)
+      if (bless)
+	{
+	  if (fargc != 1)
 	    {
-	      hfsutil_perrorp(fargv[i]);
+	      fprintf(stderr, "%s: %s: ambiguous path\n", argv0, argv[i]);
 	      result = 1;
 	    }
 	  else
 	    {
-	      if (! (ent.flags & HFS_ISDIR))
+	      hfsvolent volent;
+
+	      if (hfs_stat(vol, fargv[0], &ent) == -1 ||
+		  hfs_vstat(vol, &volent) == -1)
 		{
-		  if (type)
-		    memcpy(ent.u.file.type, type, 4);
-		  if (crea)
-		    memcpy(ent.u.file.creator, crea, 4);
+		  hfsutil_perrorp(fargv[0]);
+		  result = 1;
 		}
+	      else
+		{
+		  volent.blessed = ent.cnid;
 
-	      if (invis < 0)
-		ent.fdflags &= ~HFS_FNDR_ISINVISIBLE;
-	      else if (invis > 0)
-		ent.fdflags |= HFS_FNDR_ISINVISIBLE;
-
-	      if (lock < 0)
-		ent.flags &= ~HFS_ISLOCKED;
-	      else if (lock > 0)
-		ent.flags |= HFS_ISLOCKED;
-
-	      if (hfs_setattr(vol, fargv[i], &ent) == -1)
+		  if (hfs_vsetattr(vol, &volent) == -1)
+		    {
+		      hfsutil_perrorp(fargv[0]);
+		      result = 1;
+		    }
+		}
+	    }
+	}
+      else
+	{
+	  for (i = 0; i < fargc; ++i)
+	    {
+	      if (hfs_stat(vol, fargv[i], &ent) == -1)
 		{
 		  hfsutil_perrorp(fargv[i]);
 		  result = 1;
 		}
+	      else
+		{
+		  if (! (ent.flags & HFS_ISDIR))
+		    {
+		      if (type)
+			memcpy(ent.u.file.type, type, 4);
+		      if (crea)
+			memcpy(ent.u.file.creator, crea, 4);
+		    }
+
+		  if (invis < 0)
+		    ent.fdflags &= ~HFS_FNDR_ISINVISIBLE;
+		  else if (invis > 0)
+		    ent.fdflags |= HFS_FNDR_ISINVISIBLE;
+
+		  if (lock < 0)
+		    ent.flags &= ~HFS_ISLOCKED;
+		  else if (lock > 0)
+		    ent.flags |= HFS_ISLOCKED;
+
+		  if (hfs_setattr(vol, fargv[i], &ent) == -1)
+		    {
+		      hfsutil_perrorp(fargv[i]);
+		      result = 1;
+		    }
+		}
 	    }
 	}
     }
