@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hcd.c,v 1.7 1998/04/11 08:26:56 rob Exp $
+ * $Id: hcd.c,v 1.8 1998/11/02 22:08:30 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -41,7 +41,7 @@ int hcd_main(int argc, char *argv[])
   mountent *ment;
   hfsvol *vol;
   hfsvolent vent;
-  char *path, root[29];
+  char *path, root[HFS_MAX_VLEN + 1 + 1];
   int fargc;
   char **fargv = 0;
   int result = 0;
