@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hformat.c,v 1.8 1998/04/11 08:26:57 rob Exp $
+ * $Id: hformat.c,v 1.9 1998/11/02 22:08:31 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -57,13 +57,13 @@ void usage(void)
  * DESCRIPTION:	call hfs_format() with necessary privileges
  */
 static
-hfsvol *do_format(const char *path, int partno, const char *vname)
+hfsvol *do_format(const char *path, int partno, int mode, const char *vname)
 {
   hfsvol *vol = 0;
 
   suid_enable();
 
-  if (hfs_format(path, partno, vname, 0, 0) != -1)
+  if (hfs_format(path, partno, mode, vname, 0, 0) != -1)
     vol = hfs_mount(path, partno, HFS_MODE_ANY);
 
   suid_disable();
@@ -160,7 +160,7 @@ int hformat_main(int argc, char *argv[])
 	partno = 1;
     }
 
-  vol = do_format(path, partno, vname);
+  vol = do_format(path, partno, 0, vname);
   if (vol == 0)
     {
       hfsutil_perror(path);
