@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# $Id: hfs.tcl,v 1.16 1998/01/10 20:31:51 rob Exp $
+# $Id: hfs.tcl,v 1.9 1998/08/31 04:27:18 rob Exp $
 #
 
 proc ctime {secs} {
@@ -262,6 +262,18 @@ proc hrename {src dst} {
     $vol rename $src $dst
 }
 
+proc hbless {path} {
+    getvol vol
+
+    set globbed [$vol glob [list $path]]
+    if {[llength $globbed] != 1} {
+	error "$path: ambiguous path"
+    }
+    set path [lindex $globbed 0]
+
+    $vol bless $path
+}
+
 proc hcat {path} {
     getvol vol
 
