@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: main.c,v 1.7 1998/04/11 08:27:08 rob Exp $
+ * $Id: main.c,v 1.8 1998/11/02 22:08:50 rob Exp $
  */
 
 # include <stdio.h>
@@ -166,7 +166,7 @@ int main(int argc, char *argv[])
 	pnum = 1;
     }
 
-  v_init(&vol, 0);
+  v_init(&vol, HFS_OPT_NOCACHE);
 
   if (REPAIR)
     {
