@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hfsutil.c,v 1.8 1998/04/11 08:26:57 rob Exp $
+ * $Id: hfsutil.c,v 1.9 1998/09/28 23:21:49 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -275,7 +275,7 @@ char **hfsutil_glob(hfsvol *vol, int argc, char *argv[],
  */
 char *hfsutil_getcwd(hfsvol *vol)
 {
-  char *path, name[33];
+  char *path, name[HFS_MAX_FLEN + 1 + 1];
   long cwd;
   int pathlen;
 
@@ -359,42 +359,41 @@ char *hfsutil_abspath(const char *path)
 	return 0;
 
       strcpy(buf, cwd);
-
-      goto finish;
     }
-
-  len = 32;
-  cwd = malloc(len);
-  if (cwd == 0)
-    return 0;
-
-  while (getcwd(cwd, len) == 0)
+  else
     {
-      if (errno != ERANGE)
+      len = 32;
+      cwd = malloc(len);
+      if (cwd == 0)
+	return 0;
+
+      while (getcwd(cwd, len) == 0)
 	{
-	  free(cwd);
-	  return 0;
+	  if (errno != ERANGE)
+	    {
+	      free(cwd);
+	      return 0;
+	    }
+
+	  len <<= 1;
+	  buf = realloc(cwd, len);
+	  if (buf == 0)
+	    {
+	      free(cwd);
+	      return 0;
+	    }
+
+	  cwd = buf;
 	}
 
-      len <<= 1;
-      buf = realloc(cwd, len);
+      buf = realloc(cwd, strlen(cwd) + 1 + strlen(path) + 1);
       if (buf == 0)
 	{
 	  free(cwd);
 	  return 0;
 	}
-
-      cwd = buf;
     }
 
-  buf = realloc(cwd, strlen(cwd) + 1 + strlen(path) + 1);
-  if (buf == 0)
-    {
-      free(cwd);
-      return 0;
-    }
-
-finish:
   strcat(buf, "/");
   strcat(buf, path);
 
