@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hls.c,v 1.7 1998/04/11 08:26:57 rob Exp $
+ * $Id: hls.c,v 1.8 1998/09/28 23:21:50 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -486,7 +486,7 @@ void show_many(int sz, queueent *ents, char **strs,
 
   for (row = 0; row < rows; ++row)
     {
-      i   = row;
+      i = row;
 
       while (1)
 	{
@@ -854,10 +854,8 @@ int hls_main(int argc, char *argv[])
   if (strcmp(bargv0, "hdir") == 0)
     options = (options & ~F_MASK) | F_LONG;
 
-  width = 80;
-  ptr = getenv("COLUMNS");
-  if (ptr)
-    width = atoi(ptr);
+  ptr   = getenv("COLUMNS");
+  width = ptr ? atoi(ptr) : 80;
 
 # ifdef TIOCGWINSZ
   {
