@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: block.h,v 1.9 1998/09/01 19:59:38 rob Exp $
+ * $Id: block.h,v 1.10 1998/11/02 22:08:53 rob Exp $
  */
 
 int b_init(hfsvol *);
@@ -33,3 +33,8 @@ int b_readab(hfsvol *, unsigned int, unsigned int, block *);
 int b_writeab(hfsvol *, unsigned int, unsigned int, const block *);
 
 unsigned long b_size(hfsvol *);
+
+# ifdef DEBUG
+void b_showstats(const bcache *);
+void b_dumpcache(const bcache *);
+# endif
