@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: btree.c,v 1.9 1998/09/10 04:56:06 rob Exp $
+ * $Id: btree.c,v 1.10 1998/11/02 22:08:54 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -464,7 +464,7 @@ fail:
  * NAME:	btree->insert()
  * DESCRIPTION:	insert a new node record into a tree
  */
-int bt_insert(btree *bt, const byte *record, int reclen)
+int bt_insert(btree *bt, const byte *record, unsigned int reclen)
 {
   node root;
   byte newrec[HFS_MAX_RECLEN];
@@ -496,7 +496,7 @@ int bt_insert(btree *bt, const byte *record, int reclen)
   if (reclen)
     {
       byte oroot[HFS_MAX_RECLEN];
-      int orootlen;
+      unsigned int orootlen;
 
       /* root node was split; create a new root */
 
