@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: btree.h,v 1.7 1998/09/10 04:56:07 rob Exp $
+ * $Id: btree.h,v 1.8 1998/11/02 22:08:55 rob Exp $
  */
 
 int bt_getnode(node *, btree *, unsigned long);
@@ -27,7 +27,7 @@ int bt_writehdr(btree *);
 
 int bt_space(btree *, unsigned int);
 
-int bt_insert(btree *, const byte *, int);
+int bt_insert(btree *, const byte *, unsigned int);
 int bt_delete(btree *, const byte *);
 
 int bt_search(btree *, const byte *, node *);
