@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: data.c,v 1.6 1998/04/11 08:27:12 rob Exp $
+ * $Id: data.c,v 1.7 1998/11/02 22:08:57 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -84,7 +84,7 @@ unsigned char hfs_charorder[256] = {
  * NAME:	data->getsb()
  * DESCRIPTION:	marshal 1 signed byte into local host format
  */
-signed char d_getsb(const unsigned char *ptr)
+signed char d_getsb(register const unsigned char *ptr)
 {
   return ptr[0];
 }
@@ -93,7 +93,7 @@ signed char d_getsb(const unsigned char *ptr)
  * NAME:	data->getub()
  * DESCRIPTION:	marshal 1 unsigned byte into local host format
  */
-unsigned char d_getub(const unsigned char *ptr)
+unsigned char d_getub(register const unsigned char *ptr)
 {
   return ptr[0];
 }
@@ -102,7 +102,7 @@ unsigned char d_getub(const unsigned char *ptr)
  * NAME:	data->getsw()
  * DESCRIPTION:	marshal 2 signed bytes into local host format
  */
-signed short d_getsw(const unsigned char *ptr)
+signed short d_getsw(register const unsigned char *ptr)
 {
   return
     (((  signed short) ptr[0] << 8) |
@@ -113,7 +113,7 @@ signed short d_getsw(const unsigned char *ptr)
  * NAME:	data->getuw()
  * DESCRIPTION:	marshal 2 unsigned bytes into local host format
  */
-unsigned short d_getuw(const unsigned char *ptr)
+unsigned short d_getuw(register const unsigned char *ptr)
 {
   return
     (((unsigned short) ptr[0] << 8) |
@@ -124,7 +124,7 @@ unsigned short d_getuw(const unsigned char *ptr)
  * NAME:	data->getsl()
  * DESCRIPTION:	marshal 4 signed bytes into local host format
  */
-signed long d_getsl(const unsigned char *ptr)
+signed long d_getsl(register const unsigned char *ptr)
 {
   return
     (((  signed long) ptr[0] << 24) |
@@ -137,7 +137,7 @@ signed long d_getsl(const unsigned char *ptr)
  * NAME:	data->getul()
  * DESCRIPTION:	marshal 4 unsigned bytes into local host format
  */
-unsigned long d_getul(const unsigned char *ptr)
+unsigned long d_getul(register const unsigned char *ptr)
 {
   return
     (((unsigned long) ptr[0] << 24) |
@@ -150,7 +150,8 @@ unsigned long d_getul(const unsigned char *ptr)
  * NAME:	data->putsb()
  * DESCRIPTION:	marshal 1 signed byte out in big-endian format
  */
-void d_putsb(unsigned char *ptr, signed char data)
+void d_putsb(register unsigned char *ptr,
+	     register signed char data)
 {
   *ptr = data;
 }
@@ -159,7 +160,8 @@ void d_putsb(unsigned char *ptr, signed char data)
  * NAME:	data->putub()
  * DESCRIPTION:	marshal 1 unsigned byte out in big-endian format
  */
-void d_putub(unsigned char *ptr, unsigned char data)
+void d_putub(register unsigned char *ptr,
+	     register unsigned char data)
 {
   *ptr = data;
 }
@@ -168,7 +170,8 @@ void d_putub(unsigned char *ptr, unsigned char data)
  * NAME:	data->putsw()
  * DESCRIPTION:	marshal 2 signed bytes out in big-endian format
  */
-void d_putsw(unsigned char *ptr, signed short data)
+void d_putsw(register unsigned char *ptr,
+	     register signed short data)
 {
   *ptr++ = ((unsigned short) data & 0xff00) >> 8;
   *ptr   = ((unsigned short) data & 0x00ff) >> 0;
@@ -178,7 +181,8 @@ void d_putsw(unsigned char *ptr, signed short data)
  * NAME:	data->putuw()
  * DESCRIPTION:	marshal 2 unsigned bytes out in big-endian format
  */
-void d_putuw(unsigned char *ptr, unsigned short data)
+void d_putuw(register unsigned char *ptr,
+	     register unsigned short data)
 {
   *ptr++ = (data & 0xff00) >> 8;
   *ptr   = (data & 0x00ff) >> 0;
@@ -188,7 +192,8 @@ void d_putuw(unsigned char *ptr, unsigned short data)
  * NAME:	data->putsl()
  * DESCRIPTION:	marshal 4 signed bytes out in big-endian format
  */
-void d_putsl(unsigned char *ptr, signed long data)
+void d_putsl(register unsigned char *ptr,
+	     register signed long data)
 {
   *ptr++ = ((unsigned long) data & 0xff000000UL) >> 24;
   *ptr++ = ((unsigned long) data & 0x00ff0000UL) >> 16;
@@ -200,7 +205,8 @@ void d_putsl(unsigned char *ptr, signed long data)
  * NAME:	data->putul()
  * DESCRIPTION:	marshal 4 unsigned bytes out in big-endian format
  */
-void d_putul(unsigned char *ptr, unsigned long data)
+void d_putul(register unsigned char *ptr,
+	     register unsigned long data)
 {
   *ptr++ = (data & 0xff000000UL) >> 24;
   *ptr++ = (data & 0x00ff0000UL) >> 16;
@@ -212,7 +218,8 @@ void d_putul(unsigned char *ptr, unsigned long data)
  * NAME:	data->fetchsb()
  * DESCRIPTION:	incrementally retrieve a signed byte of data
  */
-void d_fetchsb(const unsigned char **ptr, signed char *dest)
+void d_fetchsb(register const unsigned char **ptr,
+	       register signed char *dest)
 {
   *dest = *(*ptr)++;
 }
@@ -221,7 +228,8 @@ void d_fetchsb(const unsigned char **ptr, signed char *dest)
  * NAME:	data->fetchub()
  * DESCRIPTION:	incrementally retrieve an unsigned byte of data
  */
-void d_fetchub(const unsigned char **ptr, unsigned char *dest)
+void d_fetchub(register const unsigned char **ptr,
+	       register unsigned char *dest)
 {
   *dest = *(*ptr)++;
 }
@@ -230,7 +238,8 @@ void d_fetchub(const unsigned char **ptr, unsigned char *dest)
  * NAME:	data->fetchsw()
  * DESCRIPTION:	incrementally retrieve a signed word of data
  */
-void d_fetchsw(const unsigned char **ptr, signed short *dest)
+void d_fetchsw(register const unsigned char **ptr,
+	       register signed short *dest)
 {
   *dest =
     (((  signed short) (*ptr)[0] << 8) |
@@ -242,7 +251,8 @@ void d_fetchsw(const unsigned char **ptr, signed short *dest)
  * NAME:	data->fetchuw()
  * DESCRIPTION:	incrementally retrieve an unsigned word of data
  */
-void d_fetchuw(const unsigned char **ptr, unsigned short *dest)
+void d_fetchuw(register const unsigned char **ptr,
+	       register unsigned short *dest)
 {
   *dest =
     (((unsigned short) (*ptr)[0] << 8) |
@@ -254,7 +264,8 @@ void d_fetchuw(const unsigned char **ptr, unsigned short *dest)
  * NAME:	data->fetchsl()
  * DESCRIPTION:	incrementally retrieve a signed long word of data
  */
-void d_fetchsl(const unsigned char **ptr, signed long *dest)
+void d_fetchsl(register const unsigned char **ptr,
+	       register signed long *dest)
 {
   *dest =
     (((  signed long) (*ptr)[0] << 24) |
@@ -268,7 +279,8 @@ void d_fetchsl(const unsigned char **ptr, signed long *dest)
  * NAME:	data->fetchul()
  * DESCRIPTION:	incrementally retrieve an unsigned long word of data
  */
-void d_fetchul(const unsigned char **ptr, unsigned long *dest)
+void d_fetchul(register const unsigned char **ptr,
+	       register unsigned long *dest)
 {
   *dest =
     (((unsigned long) (*ptr)[0] << 24) |
@@ -282,7 +294,8 @@ void d_fetchul(const unsigned char **ptr, unsigned long *dest)
  * NAME:	data->storesb()
  * DESCRIPTION:	incrementally store a signed byte of data
  */
-void d_storesb(unsigned char **ptr, signed char data)
+void d_storesb(register unsigned char **ptr,
+	       register signed char data)
 {
   *(*ptr)++ = data;
 }
@@ -291,7 +304,8 @@ void d_storesb(unsigned char **ptr, signed char data)
  * NAME:	data->storeub()
  * DESCRIPTION:	incrementally store an unsigned byte of data
  */
-void d_storeub(unsigned char **ptr, unsigned char data)
+void d_storeub(register unsigned char **ptr,
+	       register unsigned char data)
 {
   *(*ptr)++ = data;
 }
@@ -300,7 +314,8 @@ void d_storeub(unsigned char **ptr, unsigned char data)
  * NAME:	data->storesw()
  * DESCRIPTION:	incrementally store a signed word of data
  */
-void d_storesw(unsigned char **ptr, signed short data)
+void d_storesw(register unsigned char **ptr,
+	       register signed short data)
 {
   *(*ptr)++ = ((unsigned short) data & 0xff00) >> 8;
   *(*ptr)++ = ((unsigned short) data & 0x00ff) >> 0;
@@ -310,7 +325,8 @@ void d_storesw(unsigned char **ptr, signed short data)
  * NAME:	data->storeuw()
  * DESCRIPTION:	incrementally store an unsigned word of data
  */
-void d_storeuw(unsigned char **ptr, unsigned short data)
+void d_storeuw(register unsigned char **ptr,
+	       register unsigned short data)
 {
   *(*ptr)++ = (data & 0xff00) >> 8;
   *(*ptr)++ = (data & 0x00ff) >> 0;
@@ -320,7 +336,8 @@ void d_storeuw(unsigned char **ptr, unsigned short data)
  * NAME:	data->storesl()
  * DESCRIPTION:	incrementally store a signed long word of data
  */
-void d_storesl(unsigned char **ptr, signed long data)
+void d_storesl(register unsigned char **ptr,
+	       register signed long data)
 {
   *(*ptr)++ = ((unsigned long) data & 0xff000000UL) >> 24;
   *(*ptr)++ = ((unsigned long) data & 0x00ff0000UL) >> 16;
@@ -332,7 +349,8 @@ void d_storesl(unsigned char **ptr, signed long data)
  * NAME:	data->storeul()
  * DESCRIPTION:	incrementally store an unsigned long word of data
  */
-void d_storeul(unsigned char **ptr, unsigned long data)
+void d_storeul(register unsigned char **ptr,
+	       register unsigned long data)
 {
   *(*ptr)++ = (data & 0xff000000UL) >> 24;
   *(*ptr)++ = (data & 0x00ff0000UL) >> 16;
