@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hfs.h,v 1.10 1998/08/31 04:27:27 rob Exp $
+ * $Id: hfs.h,v 1.11 1998/11/02 22:09:01 rob Exp $
  */
 
 # include <time.h>
@@ -48,14 +48,14 @@ typedef struct {
   time_t mddate;		/* last volume modification date */
   time_t bkdate;		/* last volume backup date */
 
-  long blessed;			/* CNID of MacOS System Folder */
+  unsigned long blessed;	/* CNID of MacOS System Folder */
 } hfsvolent;
 
 typedef struct {
   char name[HFS_MAX_FLEN + 1];	/* catalog name (MacOS Standard Roman) */
   int flags;			/* bit flags */
-  long cnid;			/* catalog node id (CNID) */
-  long parid;			/* CNID of parent directory */
+  unsigned long cnid;		/* catalog node id (CNID) */
+  unsigned long parid;		/* CNID of parent directory */
 
   time_t crdate;		/* date of creation */
   time_t mddate;		/* date of last modification */
@@ -90,8 +90,8 @@ typedef struct {
   } u;
 } hfsdirent;
 
-# define HFS_ISDIR		0x01
-# define HFS_ISLOCKED		0x02
+# define HFS_ISDIR		0x0001
+# define HFS_ISLOCKED		0x0002
 
 # define HFS_CNID_ROOTPAR	1
 # define HFS_CNID_ROOTDIR	2
@@ -121,6 +121,12 @@ extern const unsigned char hfs_charorder[];
 # define HFS_MODE_RDWR		1
 # define HFS_MODE_ANY		2
 
+# define HFS_MODE_MASK		0x0003
+
+# define HFS_OPT_NOCACHE	0x0100
+# define HFS_OPT_2048		0x0200
+# define HFS_OPT_ZERO		0x0400
+
 # define HFS_SEEK_SET		0
 # define HFS_SEEK_CUR		1
 # define HFS_SEEK_END		2
@@ -137,9 +143,9 @@ int hfs_vstat(hfsvol *, hfsvolent *);
 int hfs_vsetattr(hfsvol *, hfsvolent *);
 
 int hfs_chdir(hfsvol *, const char *);
-long hfs_getcwd(hfsvol *);
-int hfs_setcwd(hfsvol *, long);
-int hfs_dirinfo(hfsvol *, long *, char *);
+unsigned long hfs_getcwd(hfsvol *);
+int hfs_setcwd(hfsvol *, unsigned long);
+int hfs_dirinfo(hfsvol *, unsigned long *, char *);
 
 hfsdir *hfs_opendir(hfsvol *, const char *);
 int hfs_readdir(hfsdir *, hfsdirent *);
@@ -149,10 +155,10 @@ hfsfile *hfs_create(hfsvol *, const char *, const char *, const char *);
 hfsfile *hfs_open(hfsvol *, const char *);
 int hfs_setfork(hfsfile *, int);
 int hfs_getfork(hfsfile *);
-long hfs_read(hfsfile *, void *, unsigned long);
-long hfs_write(hfsfile *, const void *, unsigned long);
+unsigned long hfs_read(hfsfile *, void *, unsigned long);
+unsigned long hfs_write(hfsfile *, const void *, unsigned long);
 int hfs_truncate(hfsfile *, unsigned long);
-long hfs_seek(hfsfile *, long, int);
+unsigned long hfs_seek(hfsfile *, long, int);
 int hfs_close(hfsfile *);
 
 int hfs_stat(hfsvol *, const char *, hfsdirent *);
@@ -170,4 +176,5 @@ int hfs_zero(const char *, unsigned int, unsigned long *);
 int hfs_mkpart(const char *, unsigned long);
 int hfs_nparts(const char *);
 
-int hfs_format(const char *, int, const char *, int, const unsigned long []);
+int hfs_format(const char *, int, int,
+	       const char *, unsigned int, const unsigned long []);
