@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: medium.c,v 1.3 1998/04/11 08:27:13 rob Exp $
+ * $Id: medium.c,v 1.4 1998/11/02 22:09:04 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -74,7 +74,7 @@ int m_zeroddr(hfsvol *vol)
 int m_zeropm(hfsvol *vol, unsigned int maxparts)
 {
   Partition map;
-  int i;
+  unsigned int i;
 
   ASSERT(vol->pnum == 0 && vol->vlen != 0);
 
@@ -127,6 +127,21 @@ int m_zeropm(hfsvol *vol, unsigned int maxparts)
   if (l_putpmentry(vol, &map, 2) == -1)
     goto fail;
 
+  /* zero rest of partition map's partition */
+
+  if (maxparts > 2)
+    {
+      block b;
+
+      memset(&b, 0, sizeof(b));
+
+      for (i = 3; i <= maxparts; ++i)
+	{
+	  if (b_writepb(vol, i, &b, 1) == -1)
+	    goto fail;
+	}
+    }
+
   return 0;
 
 fail:
@@ -290,7 +305,7 @@ int m_zerobb(hfsvol *vol)
 {
   block b;
 
-  memset(b, 0, HFS_BLOCKSZ);
+  memset(&b, 0, sizeof(b));
 
   if (b_writelb(vol, 0, &b) == -1 ||
       b_writelb(vol, 1, &b) == -1)
