@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: memcmp.c,v 1.5 1998/01/08 21:15:25 rob Exp $
+ * $Id: memcmp.c,v 1.6 1998/04/11 16:22:48 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -31,7 +31,7 @@
  */
 int memcmp(const void *s1, const void *s2, size_t n)
 {
-  const unsigned char *c1, *c2;
+  register const unsigned char *c1, *c2;
 
   c1 = s1;
   c2 = s2;
