@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: node.c,v 1.8 1998/09/10 04:56:10 rob Exp $
+ * $Id: node.c,v 1.9 1998/11/02 22:09:05 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -35,12 +35,13 @@
 /* total bytes used by records (NOT including record offsets) */
 
 # define NODEUSED(n)	\
-  ((n).roff[(n).nd.ndNRecs] - (n).roff[0])
+  ((size_t) ((n).roff[(n).nd.ndNRecs] - (n).roff[0]))
 
 /* total bytes available for new records (INCLUDING record offsets) */
 
 # define NODEFREE(n)	\
-  (HFS_BLOCKSZ - (n).roff[(n).nd.ndNRecs] - 2 * ((n).nd.ndNRecs + 1))
+  ((size_t) (HFS_BLOCKSZ - (n).roff[(n).nd.ndNRecs] -  \
+	     2 * ((n).nd.ndNRecs + 1)))
 
 /*
  * NAME:	node->init()
@@ -49,7 +50,7 @@
 void n_init(node *np, btree *bt, int type, int height)
 {
   np->bt   = bt;
-  np->nnum = -1;
+  np->nnum = (unsigned long) -1;
 
   np->nd.ndFLink   = 0;
   np->nd.ndBLink   = 0;
@@ -61,7 +62,7 @@ void n_init(node *np, btree *bt, int type, int height)
   np->rnum    = -1;
   np->roff[0] = 0x00e;
 
-  memset(np->data, 0, sizeof(np->data));
+  memset(&np->data, 0, sizeof(np->data));
 }
 
 /*
@@ -222,7 +223,7 @@ int n_search(node *np, const byte *pkey)
  * NAME:	node->index()
  * DESCRIPTION:	create an index record from a key and node pointer
  */
-void n_index(const node *np, byte *record, int *reclen)
+void n_index(const node *np, byte *record, unsigned int *reclen)
 {
   const byte *key = HFS_NODEREC(*np, 0);
 
@@ -230,7 +231,7 @@ void n_index(const node *np, byte *record, int *reclen)
     {
       /* force the key length to be 0x25 */
 
-      HFS_RECKEYLEN(record) = 0x25;
+      HFS_SETKEYLEN(record, 0x25);
       memset(record + 1, 0, 0x25);
       memcpy(record + 1, key + 1, HFS_RECKEYLEN(key));
     }
@@ -248,7 +249,7 @@ void n_index(const node *np, byte *record, int *reclen)
  * DESCRIPTION:	divide a node into two and insert a record
  */
 static
-int split(node *left, byte *record, int *reclen)
+int split(node *left, byte *record, unsigned int *reclen)
 {
   btree *bt = left->bt;
   node n, *right = &n, *side = 0;
@@ -284,7 +285,7 @@ int split(node *left, byte *record, int *reclen)
 
       mark -= HFS_RECLEN(*np, i) + 2;
 
-      HFS_RECKEYLEN(rec) = 0;
+      HFS_SETKEYLEN(rec, 0);
 
       if (left->rnum == i)
 	{
@@ -342,7 +343,7 @@ fail:
  * NAME:	node->insertx()
  * DESCRIPTION:	insert a record into a node (which must already have room)
  */
-void n_insertx(node *np, const byte *record, int reclen)
+void n_insertx(node *np, const byte *record, unsigned int reclen)
 {
   int rnum, i;
   byte *ptr;
@@ -369,7 +370,7 @@ void n_insertx(node *np, const byte *record, int reclen)
  * NAME:	node->insert()
  * DESCRIPTION:	insert a new record into a node; return a record for parent
  */
-int n_insert(node *np, byte *record, int *reclen)
+int n_insert(node *np, byte *record, unsigned int *reclen)
 {
   /* check for free space */
 
@@ -410,7 +411,7 @@ int join(node *left, node *right, byte *record, int *flag)
   if (n_free(right) == -1)
     goto fail;
 
-  HFS_RECKEYLEN(record) = 0;
+  HFS_SETKEYLEN(record, 0);
   *flag = 1;
 
   return 0;
@@ -425,11 +426,11 @@ fail:
  */
 int n_delete(node *np, byte *record, int *flag)
 {
-  const byte *rec;
+  byte *rec;
 
   rec = HFS_NODEREC(*np, np->rnum);
 
-  HFS_RECKEYLEN(rec) = 0;
+  HFS_SETKEYLEN(rec, 0);
   compact(np);
 
   if (np->nd.ndNRecs == 0)
@@ -437,7 +438,7 @@ int n_delete(node *np, byte *record, int *flag)
       if (n_free(np) == -1)
 	goto fail;
 
-      HFS_RECKEYLEN(record) = 0;
+      HFS_SETKEYLEN(record, 0);
       *flag = 1;
 
       return 0;
