@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: node.h,v 1.6 1998/04/11 08:27:13 rob Exp $
+ * $Id: node.h,v 1.7 1998/11/02 22:09:06 rob Exp $
  */
 
 void n_init(node *, btree *, int, int);
@@ -26,9 +26,9 @@ int n_free(node *);
 
 int n_search(node *, const byte *);
 
-void n_index(const node *, byte *, int *);
+void n_index(const node *, byte *, unsigned int *);
 
-void n_insertx(node *, const byte *, int);
-int n_insert(node *, byte *, int *);
+void n_insertx(node *, const byte *, unsigned int);
+int n_insert(node *, byte *, unsigned int *);
 
 int n_delete(node *, byte *, int *);
