@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: os.h,v 1.5 1998/04/11 08:27:13 rob Exp $
+ * $Id: os.h,v 1.6 1998/09/15 19:21:05 rob Exp $
  */
 
 int os_open(void **, const char *, int);
@@ -24,6 +24,6 @@ int os_close(void **);
 
 int os_same(void **, const char *);
 
-long os_seek(void **, long, int);
-long os_read(void **, void *, unsigned long);
-long os_write(void **, const void *, unsigned long);
+unsigned long os_seek(void **, unsigned long);
+unsigned long os_read(void **, void *, unsigned long);
+unsigned long os_write(void **, const void *, unsigned long);
