@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: record.c,v 1.8 1998/04/11 08:27:14 rob Exp $
+ * $Id: record.c,v 1.9 1998/11/02 22:09:07 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -33,7 +33,7 @@
  * NAME:	record->packcatkey()
  * DESCRIPTION:	pack a catalog record key
  */
-void r_packcatkey(const CatKeyRec *key, byte *pkey, int *len)
+void r_packcatkey(const CatKeyRec *key, byte *pkey, unsigned int *len)
 {
   const byte *start = pkey;
 
@@ -64,7 +64,7 @@ void r_unpackcatkey(const byte *pkey, CatKeyRec *key)
  * NAME:	record->packextkey()
  * DESCRIPTION:	pack an extents record key
  */
-void r_packextkey(const ExtKeyRec *key, byte *pkey, int *len)
+void r_packextkey(const ExtKeyRec *key, byte *pkey, unsigned int *len)
 {
   const byte *start = pkey;
 
@@ -128,7 +128,7 @@ int r_compareextkeys(const ExtKeyRec *key1, const ExtKeyRec *key2)
  * NAME:	record->packcatdata()
  * DESCRIPTION:	pack catalog record data
  */
-void r_packcatdata(const CatDataRec *data, byte *pdata, int *len)
+void r_packcatdata(const CatDataRec *data, byte *pdata, unsigned int *len)
 {
   const byte *start = pdata;
   int i;
@@ -368,7 +368,7 @@ void r_unpackcatdata(const byte *pdata, CatDataRec *data)
  * NAME:	record->packextdata()
  * DESCRIPTION:	pack extent record data
  */
-void r_packextdata(const ExtDataRec *data, byte *pdata, int *len)
+void r_packextdata(const ExtDataRec *data, byte *pdata, unsigned int *len)
 {
   const byte *start = pdata;
   int i;
@@ -402,7 +402,7 @@ void r_unpackextdata(const byte *pdata, ExtDataRec *data)
  * NAME:	record->makecatkey()
  * DESCRIPTION:	construct a catalog record key
  */
-void r_makecatkey(CatKeyRec *key, long parid, const char *name)
+void r_makecatkey(CatKeyRec *key, unsigned long parid, const char *name)
 {
   int len;
 
@@ -419,7 +419,8 @@ void r_makecatkey(CatKeyRec *key, long parid, const char *name)
  * NAME:	record->makeextkey()
  * DESCRIPTION:	construct an extents record key
  */
-void r_makeextkey(ExtKeyRec *key, int fork, long fnum, unsigned int fabn)
+void r_makeextkey(ExtKeyRec *key,
+		  int fork, unsigned long fnum, unsigned int fabn)
 {
   key->xkrKeyLen = 0x07;
   key->xkrFkType = fork;
@@ -432,7 +433,7 @@ void r_makeextkey(ExtKeyRec *key, int fork, long fnum, unsigned int fabn)
  * DESCRIPTION:	create a packed catalog record
  */
 void r_packcatrec(const CatKeyRec *key, const CatDataRec *data,
-		  byte *precord, int *len)
+		  byte *precord, unsigned int *len)
 {
   r_packcatkey(key, precord, len);
   r_packcatdata(data, HFS_RECDATA(precord), len);
@@ -443,7 +444,7 @@ void r_packcatrec(const CatKeyRec *key, const CatDataRec *data,
  * DESCRIPTION:	create a packed extents record
  */
 void r_packextrec(const ExtKeyRec *key, const ExtDataRec *data,
-		  byte *precord, int *len)
+		  byte *precord, unsigned int *len)
 {
   r_packextkey(key, precord, len);
   r_packextdata(data, HFS_RECDATA(precord), len);
@@ -488,9 +489,9 @@ void r_packdirent(CatDataRec *data, const hfsdirent *ent)
       data->u.fil.filUsrWds.fdLocation.h = ent->fdlocation.h;
 
       data->u.fil.filUsrWds.fdType =
-	d_getsl((unsigned char *) ent->u.file.type);
+	d_getsl((const unsigned char *) ent->u.file.type);
       data->u.fil.filUsrWds.fdCreator =
-	d_getsl((unsigned char *) ent->u.file.creator);
+	d_getsl((const unsigned char *) ent->u.file.creator);
 
       break;
     }
@@ -500,7 +501,7 @@ void r_packdirent(CatDataRec *data, const hfsdirent *ent)
  * NAME:	record->unpackdirent()
  * DESCRIPTION:	unpack catalog information into hfsdirent structure
  */
-void r_unpackdirent(long parid, const char *name,
+void r_unpackdirent(unsigned long parid, const char *name,
 		    const CatDataRec *data, hfsdirent *ent)
 {
   strcpy(ent->name, name);
