@@ -16,29 +16,32 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: record.h,v 1.6 1998/04/11 08:27:14 rob Exp $
+ * $Id: record.h,v 1.7 1998/11/02 22:09:08 rob Exp $
  */
 
-void r_packcatkey(const CatKeyRec *, byte *, int *);
+void r_packcatkey(const CatKeyRec *, byte *, unsigned int *);
 void r_unpackcatkey(const byte *, CatKeyRec *);
 
-void r_packextkey(const ExtKeyRec *, byte *, int *);
+void r_packextkey(const ExtKeyRec *, byte *, unsigned int *);
 void r_unpackextkey(const byte *, ExtKeyRec *);
 
 int r_comparecatkeys(const CatKeyRec *, const CatKeyRec *);
 int r_compareextkeys(const ExtKeyRec *, const ExtKeyRec *);
 
-void r_packcatdata(const CatDataRec *, byte *, int *);
+void r_packcatdata(const CatDataRec *, byte *, unsigned int *);
 void r_unpackcatdata(const byte *, CatDataRec *);
 
-void r_packextdata(const ExtDataRec *, byte *, int *);
+void r_packextdata(const ExtDataRec *, byte *, unsigned int *);
 void r_unpackextdata(const byte *, ExtDataRec *);
 
-void r_makecatkey(CatKeyRec *, long, const char *);
-void r_makeextkey(ExtKeyRec *, int, long, unsigned int);
+void r_makecatkey(CatKeyRec *, unsigned long, const char *);
+void r_makeextkey(ExtKeyRec *, int, unsigned long, unsigned int);
 
-void r_packcatrec(const CatKeyRec *, const CatDataRec *, byte *, int *);
-void r_packextrec(const ExtKeyRec *, const ExtDataRec *, byte *, int *);
+void r_packcatrec(const CatKeyRec *, const CatDataRec *,
+		  byte *, unsigned int *);
+void r_packextrec(const ExtKeyRec *, const ExtDataRec *,
+		  byte *, unsigned int *);
 
 void r_packdirent(CatDataRec *, const hfsdirent *);
-void r_unpackdirent(long, const char *, const CatDataRec *, hfsdirent *);
+void r_unpackdirent(unsigned long, const char *,
+		    const CatDataRec *, hfsdirent *);
