@@ -16,11 +16,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: version.h,v 1.5 1998/04/11 08:27:15 rob Exp $
+ * $Id: version.h,v 1.6 1998/09/18 22:56:38 rob Exp $
  */
 
-extern char libhfs_rcsid[];
+extern const char libhfs_rcsid[];
 
-extern char libhfs_version[];
-extern char libhfs_copyright[];
-extern char libhfs_author[];
+extern const char libhfs_version[];
+extern const char libhfs_copyright[];
+extern const char libhfs_author[];
