@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: rsrc.c,v 1.6 1998/04/11 08:27:19 rob Exp $
+ * $Id: rsrc.c,v 1.7 1998/11/02 22:09:15 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -42,7 +42,7 @@ rsrcfile *rsrc_init(void *priv, const struct rsrcprocs *procs)
   rsrcfile *rfile;
   byte head[16];
   const byte *ptr = head;
-  long nbytes;
+  unsigned long nbytes;
   unsigned short tlistoff, nlistoff;
 
   rfile = ALLOC(rsrcfile, 1);
@@ -54,13 +54,13 @@ rsrcfile *rsrc_init(void *priv, const struct rsrcprocs *procs)
 
   rfile->map.data = 0;
 
-  if (rfile->procs.seek(rfile->priv, 0, RSRC_SEEK_SET) == -1)
+  if (rfile->procs.seek(rfile->priv, 0, RSRC_SEEK_SET) == (unsigned long) -1)
     ERROR(errno, "error seeking resource header");
 
   nbytes = rfile->procs.read(rfile->priv, head, sizeof(head));
   if (nbytes != sizeof(head))
     {
-      if (nbytes == -1)
+      if (nbytes == (unsigned long) -1)
 	ERROR(errno, "error reading resource header");
       else
 	ERROR(EINVAL, "truncated resource header");
@@ -76,13 +76,14 @@ rsrcfile *rsrc_init(void *priv, const struct rsrcprocs *procs)
   if (rfile->map.data == 0)
     ERROR(ENOMEM, 0);
 
-  if (rfile->procs.seek(rfile->priv, rfile->hdr.mstart, RSRC_SEEK_SET) == -1)
+  if (rfile->procs.seek(rfile->priv, rfile->hdr.mstart, RSRC_SEEK_SET) ==
+      (unsigned long) -1)
     ERROR(errno, "error seeking resource map");
 
   nbytes = rfile->procs.read(rfile->priv, rfile->map.data, rfile->hdr.mlen);
   if (nbytes != rfile->hdr.mlen)
     {
-      if (nbytes == -1)
+      if (nbytes == (unsigned long) -1)
 	ERROR(errno, "error reading resource map");
       else
 	ERROR(EIO, "truncated resource map");
@@ -234,7 +235,7 @@ fail:
 static
 int compare_id(rsrcmap *map, const byte *ritem, const void *key)
 {
-  return d_getsw(ritem) == *(int *) key;
+  return d_getsw(ritem) == *(const int *) key;
 }
 
 /*
@@ -260,22 +261,21 @@ int compare_name(rsrcmap *map, const byte *ritem, const void *key)
 static
 rsrchandle *load(rsrcfile *rfile, const byte *ritem)
 {
-  unsigned long offs;
-  long nbytes;
+  unsigned long offs, nbytes, len, count;
   byte data[260];
-  unsigned long len, count;
   rsrchandle *rsrc = 0;
 
   offs = d_getul(ritem + 4) & 0x00ffffff;
 
   if (rfile->procs.seek(rfile->priv,
-			rfile->hdr.dstart + offs, RSRC_SEEK_SET) == -1)
+			rfile->hdr.dstart + offs, RSRC_SEEK_SET) ==
+      (unsigned long) -1)
     ERROR(errno, "error seeking resource data");
 
   nbytes = rfile->procs.read(rfile->priv, data, sizeof(data));
   if (nbytes < 4)
     {
-      if (nbytes == -1)
+      if (nbytes == (unsigned long) -1)
 	ERROR(errno, "error reading resource data");
       else
 	ERROR(EIO, "truncated resource data");
@@ -298,7 +298,7 @@ rsrchandle *load(rsrcfile *rfile, const byte *ritem)
       nbytes = rfile->procs.read(rfile->priv, rsrc->data + count, len - count);
       if (nbytes != len - count)
 	{
-	  if (nbytes == -1)
+	  if (nbytes == (unsigned long) -1)
 	    ERROR(errno, "error reading resource data");
 	  else
 	    ERROR(EIO, "truncated resource data");
