@@ -16,14 +16,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: version.c,v 1.9 1998/09/15 19:21:38 rob Exp $
+ * $Id: version.c,v 1.11 1998/11/02 22:09:17 rob Exp $
  */
 
 # include "version.h"
 
-char librsrc_rcsid[] =
-  "$Id: version.c,v 1.9 1998/09/15 19:21:38 rob Exp $";
+const char librsrc_rcsid[] =
+  "$Id: version.c,v 1.11 1998/11/02 22:09:17 rob Exp $";
 
-char librsrc_version[]   = "librsrc version 3.2.4";
-char librsrc_copyright[] = "Copyright (C) 1996-1998 Robert Leslie";
-char librsrc_author[]    = "Robert Leslie <rob@mars.org>";
+const char librsrc_version[]   = "librsrc version 3.2.6";
+const char librsrc_copyright[] = "Copyright (C) 1996-1998 Robert Leslie";
+const char librsrc_author[]    = "Robert Leslie <rob@mars.org>";
