@@ -16,11 +16,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: version.h,v 1.5 1998/04/11 08:27:19 rob Exp $
+ * $Id: version.h,v 1.6 1998/09/18 22:56:44 rob Exp $
  */
 
-extern char librsrc_rcsid[];
+extern const char librsrc_rcsid[];
 
-extern char librsrc_version[];
-extern char librsrc_copyright[];
-extern char librsrc_author[];
+extern const char librsrc_version[];
+extern const char librsrc_copyright[];
+extern const char librsrc_author[];
