@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: tclhfs.c,v 1.10 1998/08/31 04:27:19 rob Exp $
+ * $Id: tclhfs.c,v 1.12 1998/11/02 22:08:32 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -65,7 +65,7 @@ int err_umount, err_close;
 
 typedef struct {
   hfsvol *vol;
-  long cwd;
+  unsigned long cwd;
 } volref;
 
 typedef struct {
@@ -556,7 +556,7 @@ int copynative(Tcl_Interp *interp, volref *srcvref, char *argv[])
   const char *srcname, *dstname;
   hfsfile *ifile, *ofile;
   int result;
-  long cnid;
+  unsigned long cnid;
 
   if (Tcl_GetCommandInfo(interp, argv[3], &info))
     entry = Tcl_FindHashEntry(&volumes, (char *) info.clientData);
@@ -725,7 +725,7 @@ int copyout(Tcl_Interp *interp, hfsvol *vol, char *argv[])
  * DESCRIPTION:	call hfs_zero() with necessary privileges
  */
 static
-int do_zero(const char *path, int nparts, unsigned long *len)
+int do_zero(const char *path, unsigned int nparts, unsigned long *len)
 {
   int result;
 
@@ -757,13 +757,13 @@ int do_mkpart(const char *path, unsigned long len)
  * DESCRIPTION:	call hfs_format() with necessary privileges
  */
 static
-int do_format(const char *path, int partno, const char *vname,
-	      int nbadblocks, unsigned long badblocks[])
+int do_format(const char *path, int partno, int mode, const char *vname,
+	      unsigned int nbadblocks, unsigned long badblocks[])
 {
   int result;
 
   suid_enable();
-  result = hfs_format(path, partno, vname, nbadblocks, badblocks);
+  result = hfs_format(path, partno, mode, vname, nbadblocks, badblocks);
   suid_disable();
 
   return result;
@@ -1259,7 +1259,7 @@ int cmd_hfs(ClientData clientData, Tcl_Interp *interp,
     }
   else if (strcmp(argv[1], "mkpart") == 0)
     {
-      int len;
+      unsigned int len;
 
       if (argc != 4)
 	{
@@ -1333,7 +1333,7 @@ int cmd_hfs(ClientData clientData, Tcl_Interp *interp,
 
 	  free(listv);
 
-	  if (do_format(argv[2], partno, argv[4], listc, badblocks) == -1)
+	  if (do_format(argv[2], partno, 0, argv[4], listc, badblocks) == -1)
 	    {
 	      FREE(badblocks);
 
@@ -1344,7 +1344,7 @@ int cmd_hfs(ClientData clientData, Tcl_Interp *interp,
 	}
       else
 	{
-	  if (do_format(argv[2], partno, argv[4], 0, 0) == -1)
+	  if (do_format(argv[2], partno, 0, argv[4], 0, 0) == -1)
 	    return error(interp, 0);
 	}
     }
@@ -1398,7 +1398,7 @@ int cmd_hfs(ClientData clientData, Tcl_Interp *interp,
 	  return TCL_ERROR;
 	}
 
-      interp->result = hfsutils_version;
+      interp->result = (char *) hfsutils_version;
     }
   else if (strcmp(argv[1], "copyright") == 0)
     {
@@ -1408,7 +1408,7 @@ int cmd_hfs(ClientData clientData, Tcl_Interp *interp,
 	  return TCL_ERROR;
 	}
 
-      interp->result = hfsutils_copyright;
+      interp->result = (char *) hfsutils_copyright;
     }
   else if (strcmp(argv[1], "author") == 0)
     {
@@ -1418,7 +1418,7 @@ int cmd_hfs(ClientData clientData, Tcl_Interp *interp,
 	  return TCL_ERROR;
 	}
 
-      interp->result = hfsutils_author;
+      interp->result = (char *) hfsutils_author;
     }
   else if (strcmp(argv[1], "license") == 0)
     {
@@ -1428,7 +1428,7 @@ int cmd_hfs(ClientData clientData, Tcl_Interp *interp,
 	  return TCL_ERROR;
 	}
 
-      interp->result = hfsutils_license;
+      interp->result = (char *) hfsutils_license;
     }
   else
     {
