@@ -16,19 +16,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: version.c,v 1.9 1998/09/15 19:19:43 rob Exp $
+ * $Id: version.c,v 1.11 1998/11/02 22:08:33 rob Exp $
  */
 
 # include "version.h"
 
-char hfsutils_rcsid[] =
-  "$Id: version.c,v 1.9 1998/09/15 19:19:43 rob Exp $";
+const char hfsutils_rcsid[] =
+  "$Id: version.c,v 1.11 1998/11/02 22:08:33 rob Exp $";
 
-char hfsutils_version[]   = "hfsutils version 3.2.4";
-char hfsutils_copyright[] = "Copyright (C) 1996-1998 Robert Leslie";
-char hfsutils_author[]    = "Robert Leslie <rob@mars.org>";
+const char hfsutils_version[]   = "hfsutils version 3.2.6";
+const char hfsutils_copyright[] = "Copyright (C) 1996-1998 Robert Leslie";
+const char hfsutils_author[]    = "Robert Leslie <rob@mars.org>";
 
-char hfsutils_license[] =
+const char hfsutils_license[] =
   "This program is free software; you can redistribute it and/or modify it\n"
   "under the terms of the GNU General Public License as published by the\n"
   "Free Software Foundation; either version 2 of the License, or (at your\n"
